<?php

namespace Database\Seeders;

use App\Models\Dusun;
use App\Models\User; // Pastikan model User diimport
use Illuminate\Database\Seeder;
use Illuminate\Support\Facades\Hash; // Untuk hashing password

class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     */
    public function run(): void
    {
        // 1. Seed Dusun untuk Desa Raksajaya
        // Asumsi ada beberapa dusun di Desa Raksajaya
        // Data ini fiktif, sesuaikan dengan data riil jika ada
        $dusun1 = Dusun::create([
            'nama' => 'Dusun Cikole',
            'alamat' => 'Kec. Lembang, Kabupaten Bandung Barat, Jawa Barat',
            'email' => 'cikole@gmail.com',
            'phone' => '-',
            'status' => 'aktif',
        ]);

        $dusun2 = Dusun::create([
            'nama' => 'Dusun Burujul',
            'alamat' => 'Kecamatan Jatiwangi, Kabupaten Majalengka, Jawa Barat',
            'email' => 'burujul@gmail.com',
            'phone' => '-',
            'status' => 'aktif',
        ]);

        $dusun3 = Dusun::create([
            'nama' => 'Dusun Raksajaya',
            'alamat' => 'Desa Raksajaya, Kec. Sodonghilir, Kab. Tasikmalaya',
            'email' => 'dusunraksajaya@gmail.com',
            'phone' => '081234567892',
            'status' => 'aktif',
        ]);

        $dusun4 = Dusun::create([
            'nama' => 'Dusun Banyuwaras',
            'alamat' => 'Desa Pakalongan, Kecamatan Sodonghilir, Kabupaten Tasikmalaya, Jawa Barat',
            'email' => 'banyuwaras@gmail.com',
            'phone' => '-',
            'status' => 'aktif',
        ]);

        $dusun5 = Dusun::create([
            'nama' => 'Dusun Cimencek',
            'alamat' => 'Cimencek, Kec. Samarang, Kabupaten Garut, Jawa Barat',
            'email' => 'cimencek@gmail.com',
            'phone' => '-',
            'status' => 'aktif',
        ]);

        User::create([
            'name' => 'warga',
            'email' => 'warga@gmail.com',
            'email_verified_at' => now(),
            'password' => Hash::make('warga123'),
            'role' => 'warga',
            'is_approved' => true,
            'dusun_id' => $dusun3->id,
            // 'remember_token' => Str::random(10), // Jika menggunakan Str
        ]);
        
        User::create([
            'name' => 'Admin Desa Raksajaya',
            'email' => 'desa@gmail.com',
            'email_verified_at' => now(),
            'is_approved' => true,
            'password' => Hash::make('desa123'), // Ganti dengan password yang aman
            'dusun_id' => $dusun3->id,
            'role' => 'admin_desa',
            // 'remember_token' => Str::random(10),
        ]);

        User::create([
            'name' => 'Kepala Desa Raksajaya',
            'is_approved' => true,
            'email' => 'kepdes@gmail.com',
            'email_verified_at' => now(),
            'password' => Hash::make('kepdes123'), // Ganti dengan password yang aman
            'dusun_id' => $dusun3->id,
            'role' => 'kepala_desa',
            // 'remember_token' => Str::random(10),
        ]);
    }
}